@@ -5,7 +5,6 @@ from mcpi.vec3 import Vec3
 import mcpi.block
 
 from .thing import Thing
-from .world import World
 
 
 class Collage(Thing):
@@ -14,7 +13,7 @@ class Collage(Thing):
     length = 4  # z
     change_blocks = [mcpi.block.BEDROCK, mcpi.block.SAND, mcpi.block.GOLD_BLOCK, mcpi.block.IRON_BLOCK]
 
-    def build(self):
+    def create(self):
         p = self.position
         count = 0
         for y in range(0, self.height):
@@ -23,7 +22,7 @@ class Collage(Thing):
                     block = self.block
                     if self.block != self._block_empty:
                         block = self.change_blocks[count % len(self.change_blocks)]
-                    World.server.setBlock(p.x + x, p.y + y, p.z + z, block)
+                    self.set_block(Vec3(p.x + x, p.y + y, p.z + z), block.id)
                     count += 1
 
         self._end_position = Vec3(p.x + self.width - 1, p.y + self.height - 1, p.z + self.length - 1)
