@@ -1,15 +1,14 @@
 # Licensed under the terms of http://www.apache.org/licenses/LICENSE-2.0
 # Author (©): Alvaro del Castillo
-import logging
-import math
 
 import mcpi.block
-import mcpi.vec3
+from mcpi.vec3 import Vec3
 
 from ._version import __version__
-from .scene import Scene
 
-from .utils import build_schematic_nbt, extract_region
+from .blocks_memory import BlocksMemory
+from .scene import Scene
+from .utils import build_schematic_nbt
 from .world import World
 
 
@@ -29,11 +28,12 @@ class Thing:
         :param scene: scene in which this Thing is included
         """
 
+        self._blocks_memory = BlocksMemory()
+        self._children = []
+        self._decorators = []
         self._end_position = None
         self._parent = parent
-        self._children = []
         self._position = None
-        self._decorators = []
         self._scene = scene
 
         if position:
@@ -78,13 +78,40 @@ class Thing:
         """ Add a children to this Thing  """
         self._children.append(child)
 
-    def build(self):
+    def set_block(self, pos, block_id, block_data=None):
+        self._blocks_memory.set_block(pos, block_id, block_data)
+
+    def set_blocks(self, init_pos, end_pos, block_id):
+        """ Add a cuboid with the same block for all blocks and without specific data"""
+        self._blocks_memory.set_blocks(init_pos, end_pos, block_id)
+
+    def create(self):
         """
-        Build the thing and show it in Minecraft at position coordinates
+        Create the Thing in memory (BlocksMemory)
+        :return:
+        """
+
+    def render(self):
+        """
+        Render the Thing from memory (BlocksMemory) to show it
 
         :return:
         """
 
+        World.renderer.render(self._blocks_memory)
+        for child in self._children:
+            child.render()
+
+    def build(self):
+        """
+        Build the thing and show it using the renderer at position coordinates
+
+        :return:
+        """
+
+        self.create()
+        self.render()
+
     def unbuild(self):
         """
         Unbuild the thing in Minecraft
@@ -94,6 +121,7 @@ class Thing:
 
         block = self.block
         self.block = self._block_empty
+        self._blocks_memory.blocks = []
         self.build()
         self.block = block
 
@@ -111,52 +139,18 @@ class Thing:
 
     def rotate(self, degrees):
         """
-        Rotate the thing in the x,z space. Blocks data is not preserved.
+        Rotate the thing in the x,z space using the blocks memory.
 
         :param degrees: degrees to rotate (90, 180, 270)
         :return:
         """
 
-        valid_degrees = [90, 180, 270]
+        self._blocks_memory.rotate(degrees, self.position)
 
-        if degrees not in [90, 180, 270]:
-            raise RuntimeError("Invalid degrees: %s (valid: %s) " % (degrees, valid_degrees))
-
-        cos_degrees = math.cos(math.radians(degrees))
-        sin_degrees = math.sin(math.radians(degrees))
-
-        def rotate_x(pos_x, pos_z):
-            return pos_x * cos_degrees - pos_z * sin_degrees
-
-        def rotate_z(pos_x, pos_z):
-            return pos_z * cos_degrees + pos_x * sin_degrees
-
-        if self.end_position is None:
-            self.build()
-
-        # Rotate all the blocks in the Thing
-        min_pos, max_pos = self.find_bounding_box()
-        size_x = max_pos.x - min_pos.x + 1
-        size_y = max_pos.y - min_pos.y + 1
-        size_z = max_pos.z - min_pos.z + 1
-
-        # Get all blocks to be rotated
-        blocks_to_rotate, data = extract_region(min_pos, max_pos)
-
-        # Remove all blocks
-        self.unbuild()
-
-        # Add the rotated blocks
-        for y in range(0, size_y):
-            for z in range(0, size_z):
-                for x in range(0, size_x):
-                    i = x + size_x * z + (size_x * size_z) * y
-                    b = blocks_to_rotate[i]
-                    if b != 0:
-                        rotated_x = min_pos.x + rotate_x(x, z)
-                        rotated_z = min_pos.z + rotate_z(x, z)
-                        World.server.setBlock(rotated_x, min_pos.y + y, rotated_z, b)
-                        self._end_position = mcpi.vec3.Vec3(rotated_x, min_pos.y + y, rotated_z)
+        # Update the position and end_position after the rotation
+        init_pos, end_pos = self._blocks_memory.find_init_end_pos()
+        self._position = init_pos
+        self._end_position = end_pos
 
     def to_schematic(self, file_path, blocks_data=False):
         """
@@ -185,9 +179,9 @@ class Thing:
         :return:
         """
         for decorator in self._decorators:
-            decorator.decorate(self)
+            decorator(self).decorate()
             for child in self._children:
-                decorator.decorate(child)
+                decorator(child).decorate()
 
     def find_bounding_box(self):
         """ Compute the bounding box of the Thing """
